@@ -1,6 +1,6 @@
-# $Id: Config.pm 77 2005-10-11 14:53:00Z daisuke $
+# $Id: Config.pm 43 2005-04-05 14:55:44Z daisuke $
 #
-# Copyright (c) 2005 Daisuke Maki <dmaki@cpan.org>
+# Daisuke Maki <dmaki@cpan.org>
 # All rights reserved.
 
 package Xango::Config;
@@ -9,7 +9,6 @@ use strict;
 # XXX - While YAML rocks (it really does), this may be one of
 # those modules that we need to shed to reduce memory footprint.
 # See if we need to strip out memory later
-# XXX - also, see if we can come up with a config loader of sorts.
 use YAML();
 
 my $instance;
@@ -24,16 +23,8 @@ sub import
 
 sub init
 {
-    my($class, $filename, $opts) = @_;
-    if (ref ($opts) ne 'HASH') {
-        $opts = {};
-    }
-
-    if ($opts->{force_reload}) {
-        $instance = bless YAML::LoadFile($filename), $class;
-    } else {
-        $instance ||= bless YAML::LoadFile($filename), $class;
-    }
+    my($class, $filename) = @_;
+    $instance ||= bless YAML::LoadFile($filename), $class;
     undef;
 }
 
@@ -78,41 +69,28 @@ as Perl data structures.
 
 =head1 METHODS
 
-=head2 init($filename[, \%opts])
-
-=over 4
+=head2 init($filename)
 
 Class method that initializes the config with the contents in the YAML file. 
-Once initialized, subsequent calls to init() has no effect unless 
-I<force_reload> is specified in the options hash:
-
-  Xango::Config->init($file, { force_reload => 1 });
-
-=back
+Once initialized, subsequent calls to init() has no effect.
 
 =head2 instance()
 
-=over 4
-
 Returns the current instance of Xango::Config. will return undef unless you
 have initialized the instance by calling init().
 
-=back
-
 =head2 param($name[, $value])
 
-=over 4
-
 Get/Set the value of a config variable. Returns whatever Perl structure that
 you have specified in the config file.
 
 Since Xango::Config is an You may use param() as both a class method or an instance method
 
-=back
+=head1 CONFIGURATION VARIABLES
 
 =head1 AUTHOR
 
-Copyright (c) 2005 Daisuke Maki E<lt>dmaki@cpan.orgE<gt>
+Daisuke Maki E<lt>dmaki@cpan.orgE<gt>
 Development funded by Brazil, Ltd. E<lt>http://b.razil.jpE<gt>
 
 =cut
